@@ -1,17 +1,17 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
   Copyright (C) 2001-2020 Aymeric MOIZARD amoizard@antisip.com
-  
+
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.
-  
+
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
-  
+
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -20,16 +20,16 @@
 #ifndef _INTERNAL_H_
 #define _INTERNAL_H_
 
-#if defined (HAVE_CONFIG_H)
+#if defined(HAVE_CONFIG_H)
 #include <osip-config.h>
 #endif
 
 #if defined(__PALMOS__) && (__PALMOS__ >= 0x06000000)
-#	define HAVE_CTYPE_H 1
-#	define HAVE_STRING_H 1
-#	define HAVE_SYS_TYPES_H 1
-#	define HAVE_TIME_H 1
-#	define HAVE_STDARG_H 1
+#define HAVE_CTYPE_H 1
+#define HAVE_STRING_H 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_TIME_H 1
+#define HAVE_STDARG_H 1
 
 #elif defined(__VXWORKS_OS__) || defined(__rtems__)
 #define HAVE_STRING_H 1
@@ -45,7 +45,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_STDARG_H 1
 
-#define snprintf  _snprintf
+#define snprintf _snprintf
 
 #elif defined(WIN32)
 
@@ -67,9 +67,9 @@
 
 #endif
 
-#if defined (HAVE_STRING_H)
+#if defined(HAVE_STRING_H)
 #include <string.h>
-#elif defined (HAVE_STRINGS_H)
+#elif defined(HAVE_STRINGS_H)
 #include <strings.h>
 #else
 #include <string.h>
@@ -78,7 +78,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#if defined (HAVE_SYS_TYPES_H)
+#if defined(HAVE_SYS_TYPES_H)
 #include <sys/types.h>
 #endif
 
@@ -86,7 +86,7 @@
 #include <time.h>
 #endif
 
-#if defined (HAVE_SYS_TIME_H)
+#if defined(HAVE_SYS_TIME_H)
 #include <sys/time.h>
 #endif
 
@@ -97,14 +97,12 @@
 #endif
 
 #ifdef __PSOS__
-#define VA_START(a, f)  va_start(a, f)
+#define VA_START(a, f) va_start(a, f)
 #include "pna.h"
 #include "stdlib.h"
 #include "time.h"
-#define timercmp(tvp, uvp, cmp) \
-((tvp)->tv_sec cmp (uvp)->tv_sec || \
-(tvp)->tv_sec == (uvp)->tv_sec && (tvp)->tv_usec cmp (uvp)->tv_usec)
-#define snprintf  osip_snprintf
+#define timercmp(tvp, uvp, cmp) ((tvp)->tv_sec cmp(uvp)->tv_sec || (tvp)->tv_sec == (uvp)->tv_sec && (tvp)->tv_usec cmp(uvp)->tv_usec)
+#define snprintf osip_snprintf
 #ifndef INT_MAX
 #define INT_MAX 0x7FFFFFFF
 #endif
@@ -117,11 +115,11 @@
 
 #ifndef DOXYGEN
 
-#if !( defined(__rtems__) || defined(__PALMOS__) || defined(HAVE_STRUCT_TIMEVAL) )
+#if !(defined(__rtems__) || defined(__PALMOS__) || defined(HAVE_STRUCT_TIMEVAL))
 /* Struct timeval */
 struct timeval {
-  long tv_sec;                  /* seconds */
-  long tv_usec;                 /* and microseconds */
+  long tv_sec;  /* seconds */
+  long tv_usec; /* and microseconds */
 };
 #endif
 
@@ -134,22 +132,18 @@ struct timeval {
 
 /* Is there any thread implementation available? */
 /* HAVE_PTHREAD_H is not used any more! I keep it for a while... */
-#if !defined(__VXWORKS_OS__) && !defined(__PSOS__) && \
-	!defined(WIN32) && !defined(_WIN32_WCE) && !defined(HAVE_PTHREAD_WIN32) && \
-    !defined(HAVE_PTHREAD) && !defined(HAVE_PTHREAD_H) && !defined(HAVE_PTH_PTHREAD_H)
+#if !defined(__VXWORKS_OS__) && !defined(__PSOS__) && !defined(WIN32) && !defined(_WIN32_WCE) && !defined(HAVE_PTHREAD_WIN32) && !defined(HAVE_PTHREAD) && !defined(HAVE_PTHREAD_H) && !defined(HAVE_PTH_PTHREAD_H)
 #error No thread implementation found!
 #endif
 
 /* Pthreads support: */
 /* - Unix: native Pthreads. */
 /* - Win32: Pthreads for Win32 (http://sources.redhat.com/pthreads-win32). */
-#if defined(HAVE_PTHREAD) || defined(HAVE_PTHREAD_H) || defined(HAVE_PTH_PTHREAD_H) || \
-	defined(HAVE_PTHREAD_WIN32)
+#if defined(HAVE_PTHREAD) || defined(HAVE_PTHREAD_H) || defined(HAVE_PTH_PTHREAD_H) || defined(HAVE_PTHREAD_WIN32)
 #if defined(__arc__)
 #include <ucos_ii_api.h>
 #endif
 
-
 #include <pthread.h>
 typedef pthread_t osip_thread_t;
 #endif
@@ -200,19 +194,15 @@ typedef struct {
 } osip_thread_t;
 #endif
 
-
 /* Semaphore and Mutex abstraction layer definition */
 
 /* Is there any semaphore implementation available? */
-#if !defined(HAVE_SEMAPHORE_H) && !defined(HAVE_SYS_SEM_H) && \
-    !defined(WIN32) && !defined(_WIN32_WCE) && !defined(HAVE_PTHREAD_WIN32) && \
-    !defined(__PSOS__) && !defined(__VXWORKS_OS__) && !defined(__arc__)
+#if !defined(HAVE_SEMAPHORE_H) && !defined(HAVE_SYS_SEM_H) && !defined(WIN32) && !defined(_WIN32_WCE) && !defined(HAVE_PTHREAD_WIN32) && !defined(__PSOS__) && !defined(__VXWORKS_OS__) && !defined(__arc__)
 #error No semaphore implementation found
 #endif
 
 /* Pthreads */
-#if defined(HAVE_PTHREAD) || defined(HAVE_PTHREAD_H) || defined(HAVE_PTH_PTHREAD_H) || \
-	defined(HAVE_PTHREAD_WIN32)
+#if defined(HAVE_PTHREAD) || defined(HAVE_PTHREAD_H) || defined(HAVE_PTH_PTHREAD_H) || defined(HAVE_PTHREAD_WIN32)
 typedef pthread_mutex_t osip_mutex_t;
 #endif
 
@@ -243,7 +233,7 @@ typedef sem_t osip_sem_t;
  */
 typedef sem_t osip_sem_t;
 
-#elif defined (__APPLE_CC__)
+#elif defined(__APPLE_CC__)
 #include <mach/task.h>
 #include <mach/semaphore.h>
 #include <mach/mach_init.h>
@@ -268,7 +258,7 @@ typedef struct {
 
 #if (_WIN32_WINNT >= 0x0403) && (!defined(_WIN32_WCE))
 
-#define OSIP_CRITICALSECTION_SPIN  4000
+#define OSIP_CRITICALSECTION_SPIN 4000
 typedef struct {
   CRITICAL_SECTION h;
 } osip_mutex_t;
@@ -302,7 +292,6 @@ typedef struct {
 } osip_sem_t;
 #endif
 
-
 /* Condition variable abstraction layer definition */
 
 /**
@@ -344,7 +333,6 @@ typedef struct {
 } osip_mutex_t;
 #endif
 
-
 #endif /* #ifndef OSIP_MONOTHREAD */
 
 #endif /* #ifndef DOXYGEN */
