@@ -1,23 +1,22 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
-  
+  Copyright (C) 2001-2020 Aymeric MOIZARD amoizard@antisip.com
+
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or(at your option) any later version.
-  
+
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
-  
+
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-
 #ifndef _OSIP_PROXY_AUTHENTICATION_INFO_H_
 #define _OSIP_PROXY_AUTHENTICATION_INFO_H_
 
@@ -38,11 +37,10 @@
  * Structure for Proxy-Authentication-Info headers.
  * @var osip_proxy_authentication_info_t
  */
-  typedef osip_authentication_info_t osip_proxy_authentication_info_t;
+typedef osip_authentication_info_t osip_proxy_authentication_info_t;
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -185,7 +183,6 @@ extern "C"
  */
 #define osip_proxy_authentication_info_set_opaque(header, value) osip_authentication_info_set_opaque(header, value)
 
-
 #ifdef __cplusplus
 }
 #endif
