@@ -1293,7 +1293,8 @@ void *_osip_realloc(void *ptr, size_t size, char *file, unsigned short line) {
 
 #endif
 
-#if 0 /* for windows test purpose */
+#ifdef OSIP_MEMORY_DEBUG
+/* for windows test purpose */
 #define _CRTDBG_MAP_ALLOC
 #include <crtdbg.h>
 /*
